==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/transfer/kotlin/inputs/WorkflowStepCopyStepDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.transfer.kotlin.inputs

import com.pulumi.aws.transfer.inputs.WorkflowStepCopyStepDetailsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property destinationFileLocation Specifies the location for the file being copied. Use ${Transfer:username} in this field to parametrize the destination prefix by username.
 * @property name The name of the step, used as an identifier.
 * @property overwriteExisting A flag that indicates whether or not to overwrite an existing file of the same name. The default is `FALSE`. Valid values are `TRUE` and `FALSE`.
 * @property sourceFileLocation Specifies which file to use as input to the workflow step: either the output from the previous step, or the originally uploaded file for the workflow. Enter ${previous.file} to use the previous file as the input. In this case, this workflow step uses the output file from the previous workflow step as input. This is the default value. Enter ${original.file} to use the originally-uploaded file location as input for this step.
 */
public data class WorkflowStepCopyStepDetailsArgs(
    public val destinationFileLocation:
    Output<WorkflowStepCopyStepDetailsDestinationFileLocationArgs>? = null,
    public val name: Output<String>? = null,
    public val overwriteExisting: Output<String>? = null,
    public val sourceFileLocation: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.transfer.inputs.WorkflowStepCopyStepDetailsArgs> {
    override fun toJava(): com.pulumi.aws.transfer.inputs.WorkflowStepCopyStepDetailsArgs =
        com.pulumi.aws.transfer.inputs.WorkflowStepCopyStepDetailsArgs.builder()
            .destinationFileLocation(
                destinationFileLocation?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .name(name?.applyValue({ args0 -> args0 }))
            .overwriteExisting(overwriteExisting?.applyValue({ args0 -> args0 }))
            .sourceFileLocation(sourceFileLocation?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WorkflowStepCopyStepDetailsArgs].
 */
@PulumiTagMarker
public class WorkflowStepCopyStepDetailsArgsBuilder internal constructor() {
    private var destinationFileLocation:
        Output<WorkflowStepCopyStepDetailsDestinationFileLocationArgs>? = null

    private var name: Output<String>? = null

    private var overwriteExisting: Output<String>? = null

    private var sourceFileLocation: Output<String>? = null

    /**
     * @param value Specifies the location for the file being copied. Use ${Transfer:username} in this field to parametrize the destination prefix by username.
     */
    @JvmName("nqiebxjeknwjwaxm")
    public suspend
    fun destinationFileLocation(`value`: Output<WorkflowStepCopyStepDetailsDestinationFileLocationArgs>) {
        this.destinationFileLocation = value
    }

    /**
     * @param value The name of the step, used as an identifier.
     */
    @JvmName("hlhfjmkfewjmjoim")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value A flag that indicates whether or not to overwrite an existing file of the same name. The default is `FALSE`. Valid values are `TRUE` and `FALSE`.
     */
    @JvmName("ubirendyokwknhqx")
    public suspend fun overwriteExisting(`value`: Output<String>) {
        this.overwriteExisting = value
    }

    /**
     * @param value Specifies which file to use as input to the workflow step: either the output from the previous step, or the originally uploaded file for the workflow. Enter ${previous.file} to use the previous file as the input. In this case, this workflow step uses the output file from the previous workflow step as input. This is the default value. Enter ${original.file} to use the originally-uploaded file location as input for this step.
     */
    @JvmName("nrftqolwrqutggkf")
    public suspend fun sourceFileLocation(`value`: Output<String>) {
        this.sourceFileLocation = value
    }

    /**
     * @param value Specifies the location for the file being copied. Use ${Transfer:username} in this field to parametrize the destination prefix by username.
     */
    @JvmName("xeamrlcwtrelcvwn")
    public suspend
    fun destinationFileLocation(`value`: WorkflowStepCopyStepDetailsDestinationFileLocationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.destinationFileLocation = mapped
    }

    /**
     * @param argument Specifies the location for the file being copied. Use ${Transfer:username} in this field to parametrize the destination prefix by username.
     */
    @JvmName("qlqeembvmqlxvagx")
    public suspend
    fun destinationFileLocation(argument: suspend WorkflowStepCopyStepDetailsDestinationFileLocationArgsBuilder.() -> Unit) {
        val toBeMapped = WorkflowStepCopyStepDetailsDestinationFileLocationArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.destinationFileLocation = mapped
    }

    /**
     * @param value The name of the step, used as an identifier.
     */
    @JvmName("fckaeacjfoefaaql")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value A flag that indicates whether or not to overwrite an existing file of the same name. The default is `FALSE`. Valid values are `TRUE` and `FALSE`.
     */
    @JvmName("eidybrpvjtvjmrey")
    public suspend fun overwriteExisting(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.overwriteExisting = mapped
    }

    /**
     * @param value Specifies which file to use as input to the workflow step: either the output from the previous step, or the originally uploaded file for the workflow. Enter ${previous.file} to use the previous file as the input. In this case, this workflow step uses the output file from the previous workflow step as input. This is the default value. Enter ${original.file} to use the originally-uploaded file location as input for this step.
     */
    @JvmName("hklpvuufvjuybpgf")
    public suspend fun sourceFileLocation(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceFileLocation = mapped
    }

    internal fun build(): WorkflowStepCopyStepDetailsArgs = WorkflowStepCopyStepDetailsArgs(
        destinationFileLocation = destinationFileLocation,
        name = name,
        overwriteExisting = overwriteExisting,
        sourceFileLocation = sourceFileLocation,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/transfer/kotlin/inputs/WorkflowStepCopyStepDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.transfer.kotlin.inputs

import com.pulumi.aws.transfer.inputs.WorkflowStepCopyStepDetailsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property destinationFileLocation Specifies the location for the file being copied. Use ${Transfer:username} in this field to parametrize the destination prefix by username.
 * @property name The name of the step, used as an identifier.
 * @property overwriteExisting A flag that indicates whether or not to overwrite an existing file of the same name. The default is `FALSE`. Valid values are `TRUE` and `FALSE`.
 * @property sourceFileLocation Specifies which file to use as input to the workflow step: either the output from the previous step, or the originally uploaded file for the workflow. Enter ${previous.file} to use the previous file as the input. In this case, this workflow step uses the output file from the previous workflow step as input. This is the default value. Enter ${original.file} to use the originally-uploaded file location as input for this step.
 */
public data class WorkflowStepCopyStepDetailsArgs(
    public val destinationFileLocation: Output<WorkflowStepCopyStepDetailsDestinationFileLocationArgs>? = null,
    public val name: Output<String>? = null,
    public val overwriteExisting: Output<String>? = null,
    public val sourceFileLocation: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.transfer.inputs.WorkflowStepCopyStepDetailsArgs> {
    override fun toJava(): com.pulumi.aws.transfer.inputs.WorkflowStepCopyStepDetailsArgs =
        com.pulumi.aws.transfer.inputs.WorkflowStepCopyStepDetailsArgs.builder()
            .destinationFileLocation(
                destinationFileLocation?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .name(name?.applyValue({ args0 -> args0 }))
            .overwriteExisting(overwriteExisting?.applyValue({ args0 -> args0 }))
            .sourceFileLocation(sourceFileLocation?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WorkflowStepCopyStepDetailsArgs].
 */
@PulumiTagMarker
public class WorkflowStepCopyStepDetailsArgsBuilder internal constructor() {
    private var destinationFileLocation:
        Output<WorkflowStepCopyStepDetailsDestinationFileLocationArgs>? = null

    private var name: Output<String>? = null

    private var overwriteExisting: Output<String>? = null

    private var sourceFileLocation: Output<String>? = null

    /**
     * @param value Specifies the location for the file being copied. Use ${Transfer:username} in this field to parametrize the destination prefix by username.
     */
    @JvmName("nnhlqllwtqexqiya")
    public suspend fun destinationFileLocation(`value`: Output<WorkflowStepCopyStepDetailsDestinationFileLocationArgs>) {
        this.destinationFileLocation = value
    }

    /**
     * @param value The name of the step, used as an identifier.
     */
    @JvmName("msnuyioiahgfqpmq")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value A flag that indicates whether or not to overwrite an existing file of the same name. The default is `FALSE`. Valid values are `TRUE` and `FALSE`.
     */
    @JvmName("hmdejpypxuqlkgos")
    public suspend fun overwriteExisting(`value`: Output<String>) {
        this.overwriteExisting = value
    }

    /**
     * @param value Specifies which file to use as input to the workflow step: either the output from the previous step, or the originally uploaded file for the workflow. Enter ${previous.file} to use the previous file as the input. In this case, this workflow step uses the output file from the previous workflow step as input. This is the default value. Enter ${original.file} to use the originally-uploaded file location as input for this step.
     */
    @JvmName("ogneamfdtwqnovjf")
    public suspend fun sourceFileLocation(`value`: Output<String>) {
        this.sourceFileLocation = value
    }

    /**
     * @param value Specifies the location for the file being copied. Use ${Transfer:username} in this field to parametrize the destination prefix by username.
     */
    @JvmName("baihvodkqfrxlnkb")
    public suspend fun destinationFileLocation(`value`: WorkflowStepCopyStepDetailsDestinationFileLocationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.destinationFileLocation = mapped
    }

    /**
     * @param argument Specifies the location for the file being copied. Use ${Transfer:username} in this field to parametrize the destination prefix by username.
     */
    @JvmName("yehfgvivwhvepkgx")
    public suspend fun destinationFileLocation(argument: suspend WorkflowStepCopyStepDetailsDestinationFileLocationArgsBuilder.() -> Unit) {
        val toBeMapped = WorkflowStepCopyStepDetailsDestinationFileLocationArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.destinationFileLocation = mapped
    }

    /**
     * @param value The name of the step, used as an identifier.
     */
    @JvmName("pgcrhndhpvnsltbt")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value A flag that indicates whether or not to overwrite an existing file of the same name. The default is `FALSE`. Valid values are `TRUE` and `FALSE`.
     */
    @JvmName("ybonkkrelfduwrww")
    public suspend fun overwriteExisting(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.overwriteExisting = mapped
    }

    /**
     * @param value Specifies which file to use as input to the workflow step: either the output from the previous step, or the originally uploaded file for the workflow. Enter ${previous.file} to use the previous file as the input. In this case, this workflow step uses the output file from the previous workflow step as input. This is the default value. Enter ${original.file} to use the originally-uploaded file location as input for this step.
     */
    @JvmName("grxwyjqmbbmpbcsh")
    public suspend fun sourceFileLocation(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceFileLocation = mapped
    }

    internal fun build(): WorkflowStepCopyStepDetailsArgs = WorkflowStepCopyStepDetailsArgs(
        destinationFileLocation = destinationFileLocation,
        name = name,
        overwriteExisting = overwriteExisting,
        sourceFileLocation = sourceFileLocation,
    )
}
